@@ -14,11 +14,11 @@ Archive::Har::Entry - Represents a single http request/response pair inside the
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ our $VERSION = '0.03';
         my $response = $entry->response();
         my $cache = $entry->cache();
         my $timing = $entry->pageTimings();
-        print "Server IP Address: " . $entry->serviceIPAddress() . "\n";
+        print "Server IP Address: " . $entry->serverIPAddress() . "\n";
         print "Connection: " . $entry->connection() . "\n";
         print "Comment: " . $entry->comment() . "\n";
     }
